#LIMMA
#source("http://bioconductor.org/biocLite.R")
#biocLite("limma")

logFoldChange=0.58
P=0.05

library(limma)
setwd("C:\\Users\\admin\\Desktop\\TG+SLE\\GSE81622\\05.diff")
rt=read.table("geneMatrix.txt",sep="\t",header=T,check.names=F)
rt=as.matrix(rt)
rownames(rt)=rt[,1]
exp=rt[,2:ncol(rt)]
dimnames=list(rownames(exp),colnames(exp))
rt=matrix(as.numeric(as.matrix(exp)),nrow=nrow(exp),dimnames=dimnames)
rt=avereps(rt)
rt=normalizeBetweenArrays(as.matrix(rt))
rt=log2(rt+1)

#differential
modType=c(rep("con",25),rep("treat",30))
design <- model.matrix(~0+factor(modType))
colnames(design) <- c("con","treat")
fit <- lmFit(rt,design)
cont.matrix<-makeContrasts(treat-con,levels=design)
fit2 <- contrasts.fit(fit, cont.matrix)
fit2 <- eBayes(fit2)

allDiff=topTable(fit2,adjust='fdr',number=200000)
write.table(allDiff,file="limmaTab.xls",sep="\t",quote=F)

#write table
diffSig <- allDiff[with(allDiff, (abs(logFC)>logFoldChange & P.Value < P )), ]
write.table(diffSig,file="diff.xls",sep="\t",quote=F)
diffUp <- allDiff[with(allDiff, (logFC>logFoldChange & P.Value < P )), ]
write.table(diffUp,file="up.xls",sep="\t",quote=F)
diffDown <- allDiff[with(allDiff, (logFC<(-logFoldChange) & P.Value < P )), ]
write.table(diffDown,file="down.xls",sep="\t",quote=F)

#write expression level of diff gene
hmExp=rt[rownames(diffSig),]
diffExp=rbind(id=colnames(hmExp),hmExp)
write.table(diffExp,file="heatmap.txt",sep="\t",quote=F,col.names=F)

#volcano
tiff(file="vol.tiff",
       width = 12,            #图片的宽度
       height =12,            #图片的高度
       units ="cm",
       compression="lzw",
       bg="white",
       res=600)
xMax=max(-log10(allDiff$P.Value))
yMax=max(abs(allDiff$logFC))
plot(-log10(allDiff$P.Value), allDiff$logFC, xlab="-log10(P.Value)",ylab="logFC",
     main="Volcano", xlim=c(0,xMax),ylim=c(-yMax,yMax),yaxs="i",pch=20, cex=0.8)
diffSub=subset(allDiff, P.Value<P & logFC>logFoldChange)
points(-log10(diffSub$P.Value), diffSub$logFC, pch=20, col="chocolate1",cex=0.8)
diffSub=subset(allDiff, P.Value<P & logFC<(-logFoldChange))
points(-log10(diffSub$P.Value), diffSub$logFC, pch=20, col="cyan",cex=0.8)
abline(h=0,lty=2,lwd=3)
dev.off()

#install.packages("pheatmap")

setwd("C:\\Users\\admin\\Desktop\\TG+SLE\\GSE81622\\08.pheatmap")      #设置工作目录
rt=read.table("heatmap-top100.txt",sep="\t",header=T,check.names=F)
rt=as.matrix(rt)
rownames(rt)=rt[,1]
exp=rt[,2:ncol(rt)]
dimnames=list(rownames(exp),colnames(exp))
rt=matrix(as.numeric(as.matrix(exp)),nrow=nrow(exp),dimnames=dimnames)
#rt=log2(rt+1)
#rt[rt>15]=15

library(pheatmap)
Geo=c(rep("GSE81622",55))
Type=c(rep("Control",25),rep("Systemic Lupus Erythematosus",30))    #修改正常和癌症样品数目
names(Geo)=colnames(rt)
ann=cbind(Geo,Type)
ann=as.data.frame(ann)

tiff(file="heatmap.tiff",
       width = 20,            #图片的宽度
       height =18,            #图片的高度
       units ="cm",
       compression="lzw",
       bg="white",
       res=1200)
pheatmap(rt, annotation=ann, 
         color = colorRampPalette(c("cyan", "white", "chocolate1"))(100),
         cluster_cols =F,
#         scale="row",
         fontsize_row=4,
         fontsize_col=4)
dev.off()

